@@ -2,7 +2,7 @@ package WebService::Stripe;
 use Moo;
 with 'WebService::Client';
 
-our $VERSION = '1.0100'; # VERSION
+our $VERSION = '1.0200'; # VERSION
 
 use Carp qw(croak);
 use HTTP::Request::Common qw( POST );
@@ -221,6 +221,11 @@ method get_event(Str $id, :$headers) {
     return $self->get( "/v1/events/$id", {}, headers => $headers );
 }
 
+method create_access_token(HashRef $data, :$headers) {
+    my $url = "https://connect.stripe.com/oauth/token";
+    return $self->post( $url, $data, headers => $headers );
+}
+
 # ABSTRACT: Stripe API bindings
 
 
@@ -238,7 +243,7 @@ WebService::Stripe - Stripe API bindings
 
 =head1 VERSION
 
-version 1.0100
+version 1.0200
 
 =head1 SYNOPSIS
 
@@ -575,6 +580,13 @@ Returns an event for the given id.
 Returns a list of events.
 The query param is optional.
 
+=head2 create_access_token
+
+    create_access_token($data)
+
+Creates an access token for the Stripe Connect oauth flow
+L<https://stripe.com/docs/connect/reference#post-token>
+
 =head1 AUTHORS
 
 =over 4
